/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.implement;

import java.io.IOException;
import nl.cloudfarming.client.fleet.implement.tree.ImplementNode;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.lookup.AbstractLookup;
import org.openide.util.lookup.InstanceContent;
import org.openide.util.lookup.ProxyLookup;

public class ImplementDataObject extends MultiDataObject {

    private final InstanceContent ic = new InstanceContent();
    private final Lookup lkp = new AbstractLookup(ic);

    public ImplementDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);
        registerEditor("application/x-agrosense-implement", true);
        ImplementManagerImpl implementManager = Lookup.getDefault().lookup(ImplementManagerImpl.class);
        Implement implement = implementManager.load(pf);
        ic.add(implement);
        ic.add(implement.getGeometrical());
        ic.add(new SimpleLayer(implement.getName()));
    }

    @Override
    protected int associateLookup() {
        return 1;
    }

    @Override
    protected Node createNodeDelegate() {
        return new ImplementNode(super.createNodeDelegate());
    }

    @Override
    public Lookup getLookup() {
        return new ProxyLookup(super.getLookup(), lkp);
    }
}
