/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.fleet.implement;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.*;
import nl.cloudfarming.client.fleet.machine.windows.ImagePanel;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@MultiViewElement.Registration(displayName = "#LBL_Implement_Image",
iconBase = "nl/cloudfarming/client/fleet/implement/widgets16.png",
mimeType = "application/x-agrosense-implement",
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "ImplementImage",
position = 2000)
@NbBundle.Messages("LBL_Implement_Image=Image")
public final class ImplementImageElement extends JPanel implements MultiViewElement {

    private ImplementDataObject obj;
    private Implement implement;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private ImagePanel imagePanel = new ImagePanel();

    public ImplementImageElement(Lookup lkp) {
        obj = lkp.lookup(ImplementDataObject.class);
        implement = obj.getLookup().lookup(Implement.class);
        assert obj != null;
        assert implement != null;

        setLayout(new BorderLayout());

        imagePanel.setImage(implement.getImage());

        implement.addPropertyChangeListener(Implement.PROP_IMAGE, new PropertyChangeListener() {

            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                imagePanel.setImage((ImageIcon) evt.getNewValue());
            }
        });


        ASBodyPanel overviewDecorator = new ASBodyPanel(imagePanel);
        overviewDecorator.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/implement/widgets16.png", true));
        add(overviewDecorator);

    }

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
        OpenCloseHandler.Event.triggerOpen(obj.getNodeDelegate());
    }

    @Override
    public void componentClosed() {
        OpenCloseHandler.Event.triggerClose(obj.getNodeDelegate());
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(implement.getName());
            tc.setDisplayName(implement.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
