/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.implement.wizard;

import java.io.IOException;
import java.util.Date;
import nl.cloudfarming.client.fleet.implement.tree.ImplementCategoryNodeFactory;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardAction;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardIterator;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.fleet.model.ImplementManager;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

@NbBundle.Messages(value={"wizardTitle=New implement"})
public final class ImplementWizardAction extends MachineWizardAction {
    
    public ImplementWizardAction(Project project) {
        super(project, Bundle.wizardTitle());
    }
    
    @Override
    protected MachineWizardFactory getWizardFactory() {
        return new ImplementWizardFactory(getProject());
    }

    @Override
    protected void createMachine(WizardDescriptor wiz) throws IOException {
        EnterpriseIdProvider eip = getProject().getLookup().lookup(EnterpriseIdProvider.class);
        String name = wiz.getProperty(Machine.PROP_NAME).toString();
        Implement machine = new Implement(eip, name);
        MachineDataService.Model model = (MachineDataService.Model) wiz.getProperty(MachineWizardIterator.PROP_MODEL);
        machine.setType(model.getType());
        machine.setBrand(model.getBrand());
        machine.setModelNumber(model.getModelNumber());
        machine.setYear(Integer.parseInt(wiz.getProperty(Machine.PROP_YEAR).toString()));
        machine.setPurchaseDate((Date) wiz.getProperty(Machine.PROP_PURCHASEDATE));
        machine.setPurchasePrice(Double.parseDouble(wiz.getProperty(Machine.PROP_PURCHASEPRICE).toString()));
        machine.setMileage(Integer.parseInt(wiz.getProperty(Machine.PROP_MILEAGE).toString()));

        addDynamicProperties(machine, wiz);

        Lookup.getDefault().lookup(ImplementManager.class).save(machine);
    }
}
